@@ -1,15 +1,15 @@
 /** ===========================================================
  * @file
  *
- * This file is a part of kipi-plugins project
- * <a href="http://www.digikam.org">http://www.digikam.org</a>
+ * This file is a part of KDE project
+ *
  *
  * @date   2009-11-21
  * @brief  kipi host test application
  *
  * @author Copyright (C) 2009-2010 by Michael G. Hansen
  *         <a href="mailto:mike at mghansen dot de">mike at mghansen dot de</a>
- * @author Copyright (C) 2011-2017 by Gilles Caulier
+ * @author Copyright (C) 2011-2018 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
  * @author Copyright (C) 2012 by Victor Dodon
  *         <a href="mailto:dodonvictor at gmail dot com">dodonvictor at gmail dot com</a>
@@ -58,7 +58,7 @@ int main(int argc, char* argv[])
     QApplication app(argc, argv);
     app.setApplicationName(QLatin1String("kxmlkipicmd"));
     app.setApplicationVersion(QLatin1String(KIPI_VERSION_STRING));
-    app.setOrganizationName(QLatin1String("http://www.digikam.org"));
+    app.setOrganizationName(QLatin1String("http://www.kde.org"));
     app.setWindowIcon(QIcon(QStandardPaths::locate(QStandardPaths::GenericDataLocation,
                                                    QLatin1String(":/images/kipi-icon.svg"))));
 
